@@ -11,8 +11,8 @@ class date(object):
     def getLastHourTime(self):
         return int(round(time.time() * 1000)) - 3600000
 
-    def getTimeSecond(self):
-        return int(round(time.time()))
+    def getLast24HourTime(self):
+        return int(round(time.time() * 1000)) - 86400000
 
     def getLastFiveYearTime(self):
         year = 365
