@@ -1,6 +1,6 @@
 from aishu import setting
 from aishu.datafaker.profession.entity import name, switch, ip, timestamp, ml, kai, objectManager, index, agent ,id ,port, DataManage
-from aishu.datafaker.profession.entity import zx
+from aishu.datafaker.profession.entity import zx,testMail
 from aishu.datafaker.profession.entity.ParaDateFiled import ParaDateFiledServer
 from aishu.datafaker.profession.entity.RetrievesAssociated import ParaDateAnyRobotServer
 from aishu.datafaker.profession.entity import CreateTestPort
@@ -80,7 +80,9 @@ def filed(key,inquire=[]):
         'http_port':CreateTestPort.Port().httpport,
         'syslog_port':CreateTestPort.Port().syslogPort,
         'FutureTime': ParaDateFiledServer().getFutureTime,
-        'RoleId_user': DataManage.DataManage_Storage().RoleId_user
+        'RoleId_user': DataManage.DataManage_Storage().RoleId_user,
+        'mailUser':testMail.date().getMailUser,
+        'mailpass':testMail.date().getMailPass
     }
 
     switcher = SERVICE_KPI_
